@@ -1,13 +1,13 @@
 /*-
  * See the file LICENSE for redistribution information.
  *
- * Copyright (c) 1997
+ * Copyright (c) 1997, 1998
  *	Sleepycat Software.  All rights reserved.
  */
 #include "config.h"
 
 #ifndef lint
-static const char sccsid[] = "@(#)java_DbEnv.cpp	10.2 (Sleepycat) 1/18/98";
+static const char sccsid[] = "@(#)java_DbEnv.cpp	10.4 (Sleepycat) 4/10/98";
 #endif /* not lint */
 
 #include <jni.h>
@@ -194,7 +194,7 @@ JNIEXPORT void JNICALL Java_com_sleepycat_db_DbEnv_set_1lk_1conflicts
     int len = dbenv->lk_modes;
     jsize jlen = jnienv->GetArrayLength(array);
     if (jlen != len) {
-        report_exception(jnienv, array_length_msg);
+        report_exception(jnienv, array_length_msg, 0);
         return;
     }
 
