@@ -1,13 +1,13 @@
 /*-
  * See the file LICENSE for redistribution information.
  *
- * Copyright (c) 1997
+ * Copyright (c) 1997, 1998
  *	Sleepycat Software.  All rights reserved.
  */
 #include "config.h"
 
 #ifndef lint
-static const char sccsid[] = "@(#)java_DbLsn.cpp	10.1 (Sleepycat) 11/10/97";
+static const char sccsid[] = "@(#)java_DbLsn.cpp	10.3 (Sleepycat) 5/2/98";
 #endif /* not lint */
 
 #include <jni.h>
@@ -18,10 +18,10 @@ static const char sccsid[] = "@(#)java_DbLsn.cpp	10.1 (Sleepycat) 11/10/97";
 
 #include "db.h"
 #include "java_util.h"
-#include "com_sleepycat_db_DbLog.h"
+#include "com_sleepycat_db_DbLsn.h"
 
 JNIEXPORT void JNICALL Java_com_sleepycat_db_DbLsn_init_1lsn
-  (JNIEnv *jnienv, /*DbLog*/ jobject jthis)
+  (JNIEnv *jnienv, /*DbLsn*/ jobject jthis)
 {
     DB_LSN *lsn = NEW(DB_LSN);
     memset(lsn, 0, sizeof(DB_LSN));
