@@ -1,11 +1,12 @@
 /*-
  * See the file LICENSE for redistribution information.
  *
- * Copyright (c) 1997
+ * Copyright (c) 1997, 1998
  *	Sleepycat Software.  All rights reserved.
  *
- *	@(#)java_util.h	10.2 (Sleepycat) 1/18/98
+ *	@(#)java_util.h	10.6 (Sleepycat) 5/2/98
  */
+
 #ifndef _JAVA_UTIL_H_
 #define _JAVA_UTIL_H_
 
@@ -109,6 +110,7 @@ public:
 private:
     JNIEnv *env_;
     jobject obj_;
+    jbyte *java_data_;
     int has_error_;
     int is_retrieve_op_;
 };
@@ -163,7 +165,7 @@ private:
  */
 
 #define NOT_IMPLEMENTED(str) \
-	report_exception(jnienv, str /*concatenate*/ ": not implemented")
+	report_exception(jnienv, str /*concatenate*/ ": not implemented", 0)
 
 /* Use our own malloc for any objects allocated via DB_DBT_MALLOC,
  * since we must free them in the same library address space.
@@ -210,7 +212,7 @@ void set_object_field(JNIEnv *jnienv, jclass class_of_this,
 
 /* Report an exception back to the java side.
  */
-void report_exception(JNIEnv *jnienv, const char *text);
+void report_exception(JNIEnv *jnienv, const char *text, int err);
 
 /* If the object is null, report an exception and return false (0),
  * otherwise return true (1).
@@ -251,11 +253,11 @@ DB_INFO        *get_DB_INFO       (JNIEnv *jnienv, jobject obj);
 DB_LOCK         get_DB_LOCK       (JNIEnv *jnienv, jobject obj); // not a ptr
 DB_LOCKTAB     *get_DB_LOCKTAB    (JNIEnv *jnienv, jobject obj);
 DB_LOG         *get_DB_LOG        (JNIEnv *jnienv, jobject obj);
+DB_LOG_STAT    *get_DB_LOG_STAT   (JNIEnv *jnienv, jobject obj);
 DB_LSN         *get_DB_LSN        (JNIEnv *jnienv, jobject obj);
 DB_MPOOL       *get_DB_MPOOL      (JNIEnv *jnienv, jobject obj);
 DB_MPOOL_FSTAT *get_DB_MPOOL_FSTAT(JNIEnv *jnienv, jobject obj);
 DB_MPOOL_STAT  *get_DB_MPOOL_STAT (JNIEnv *jnienv, jobject obj);
-DB_MPOOLFILE   *get_DB_MPOOLFILE  (JNIEnv *jnienv, jobject obj);
 DB_TXN         *get_DB_TXN        (JNIEnv *jnienv, jobject obj);
 DB_TXNMGR      *get_DB_TXNMGR     (JNIEnv *jnienv, jobject obj);
 DB_TXN_STAT    *get_DB_TXN_STAT   (JNIEnv *jnienv, jobject obj);
@@ -267,6 +269,7 @@ jobject get_DbBtreeStat  (JNIEnv *jnienv, DB_BTREE_STAT *dbobj);
 jobject get_Dbc          (JNIEnv *jnienv, DBC *dbobj);
 jobject get_DbLockTab    (JNIEnv *jnienv, DB_LOCKTAB *dbobj);
 jobject get_DbLog        (JNIEnv *jnienv, DB_LOG *dbobj);
+jobject get_DbLogStat    (JNIEnv *jnienv, DB_LOG_STAT *dbobj);
 jobject get_DbLsn        (JNIEnv *jnienv, DB_LSN dbobj);
 jobject get_DbMpool      (JNIEnv *jnienv, DB_MPOOL *dbobj);
 jobject get_DbMpoolStat  (JNIEnv *jnienv, DB_MPOOL_STAT *dbobj);
@@ -285,11 +288,11 @@ const char * const name_DB_INFO        = "DbInfo";
 const char * const name_DB_LOCK        = "DbLock";
 const char * const name_DB_LOCKTAB     = "DbLockTab";
 const char * const name_DB_LOG         = "DbLog";
+const char * const name_DB_LOG_STAT    = "DbLogStat";
 const char * const name_DB_LSN         = "DbLsn";
 const char * const name_DB_MPOOL       = "DbMpool";
 const char * const name_DB_MPOOL_FSTAT = "DbMpoolFStat";
 const char * const name_DB_MPOOL_STAT  = "DbMpoolStat";
-const char * const name_DB_MPOOLFILE   = "DbMpoolFile";
 const char * const name_DBT            = "Dbt";
 const char * const name_DB_TXN         = "DbTxn";
 const char * const name_DB_TXNMGR      = "DbTxnMgr";
