@@ -8,9 +8,11 @@
 #include "config.h"
 
 #ifndef lint
-static const char sccsid[] = "@(#)os_spin.c	10.4 (Sleepycat) 4/14/98";
+static const char sccsid[] = "@(#)os_spin.c	10.6 (Sleepycat) 6/2/98";
 #endif /* not lint */
 
+#include "db_int.h"
+
 /*
  * __os_spin --
  *	Return the number of default spins before blocking.
@@ -20,13 +22,12 @@ static const char sccsid[] = "@(#)os_spin.c	10.4 (Sleepycat) 4/14/98";
 int
 __os_spin()
 {
-	extern int __db_tsl_spins;
 	static long sys_val;
         SYSTEM_INFO SystemInfo;
 
 	/* If the application specified the spins, use its value. */
-	if (__db_tsl_spins != 0)
-		return (__db_tsl_spins);
+	if (DB_GLOBAL(db_tsl_spins) != 0)
+		return (DB_GLOBAL(db_tsl_spins));
 
 	/* If we've already figured this out, return the value. */
 	if (sys_val != 0)
