@@ -1,14 +1,14 @@
 /*-
  * See the file LICENSE for redistribution information.
  *
- * Copyright (c) 1996, 1997
+ * Copyright (c) 1996, 1997, 1998
  *	Sleepycat Software.  All rights reserved.
  */
 
 #include "config.h"
 
 #ifndef lint
-static const char sccsid[] = "@(#)tcl_dbm.c	10.6 (Sleepycat) 1/16/98";
+static const char sccsid[] = "@(#)tcl_dbm.c	10.8 (Sleepycat) 4/27/98";
 #endif /* not lint */
 
 /*
@@ -76,7 +76,6 @@ dbm_delete_cmd(notused, interp, argc, argv)
 	char *argv[];
 {
 	datum key;
-	int ret;
 
 	USAGE(argc, 2, DBMDEL_USAGE, 0);
 	notused = NULL;
@@ -86,7 +85,7 @@ dbm_delete_cmd(notused, interp, argc, argv)
 
 	debug_check();
 
-	if ((ret = delete(key)) == 0)
+	if (delete(key) == 0)
 		Tcl_SetResult(interp, "0", TCL_STATIC);
 	else
 		Tcl_SetResult(interp, "-1", TCL_STATIC);
@@ -131,7 +130,6 @@ dbm_store_cmd(notused, interp, argc, argv)
 	char *argv[];
 {
 	datum data, key;
-	int ret;
 
 	USAGE_GE(argc, 3, DBMSTORE_USAGE, 0);
 	notused = NULL;
@@ -144,7 +142,7 @@ dbm_store_cmd(notused, interp, argc, argv)
 
 	debug_check();
 
-	if ((ret = store(key, data)) == 0)
+	if (store(key, data) == 0)
 		Tcl_SetResult(interp, "0", TCL_STATIC);
 	else
 		Tcl_SetResult(interp, "-1", TCL_STATIC);
